@@ -13,11 +13,12 @@ Passwd::Keyring::Auto - interface to secure password storage(s)
 
 =head1 VERSION
 
-Version 0.72
+Version 0.7201
+
 
 =cut
 
-our $VERSION = '0.72';
+our $VERSION = '0.7201';
 
 =head1 SYNOPSIS
 
@@ -36,7 +37,7 @@ configuration.
 
     my $username = "someuser";
     my $password = $keyring->get_password($username, "mylostspace.com");
-    if(! $password) {
+    unless($password) {
         # ... somehow interactively prompt for password
         $keyring->set_password($username, $password, "mylostspace.com");
     }
